# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetEnvironmentResult',
    'AwaitableGetEnvironmentResult',
    'get_environment',
    'get_environment_output',
]

@pulumi.output_type
class GetEnvironmentResult:
    """
    A collection of values returned by getEnvironment.
    """
    def __init__(__self__, app_id=None, description=None, environment_id=None, id=None, name=None, type=None, variable_overrides=None):
        if app_id and not isinstance(app_id, str):
            raise TypeError("Expected argument 'app_id' to be a str")
        pulumi.set(__self__, "app_id", app_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if environment_id and not isinstance(environment_id, str):
            raise TypeError("Expected argument 'environment_id' to be a str")
        pulumi.set(__self__, "environment_id", environment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if variable_overrides and not isinstance(variable_overrides, list):
            raise TypeError("Expected argument 'variable_overrides' to be a list")
        pulumi.set(__self__, "variable_overrides", variable_overrides)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> _builtins.str:
        """
        The id of the application.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        The description of the environment.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> Optional[_builtins.str]:
        """
        The id of the environment.
        """
        return pulumi.get(self, "environment_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the environment.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the environment.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The type of the environment. Valid values are `PROD` and `NON_PROD`
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="variableOverrides")
    def variable_overrides(self) -> Sequence['outputs.GetEnvironmentVariableOverrideResult']:
        """
        Override for a service variable
        """
        return pulumi.get(self, "variable_overrides")


class AwaitableGetEnvironmentResult(GetEnvironmentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnvironmentResult(
            app_id=self.app_id,
            description=self.description,
            environment_id=self.environment_id,
            id=self.id,
            name=self.name,
            type=self.type,
            variable_overrides=self.variable_overrides)


def get_environment(app_id: Optional[_builtins.str] = None,
                    environment_id: Optional[_builtins.str] = None,
                    name: Optional[_builtins.str] = None,
                    variable_overrides: Optional[Sequence[Union['GetEnvironmentVariableOverrideArgs', 'GetEnvironmentVariableOverrideArgsDict']]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnvironmentResult:
    """
    Data source for retrieving a Harness service


    :param _builtins.str app_id: The id of the application.
    :param _builtins.str environment_id: The id of the environment.
    :param _builtins.str name: The name of the environment.
    :param Sequence[Union['GetEnvironmentVariableOverrideArgs', 'GetEnvironmentVariableOverrideArgsDict']] variable_overrides: Override for a service variable
    """
    __args__ = dict()
    __args__['appId'] = app_id
    __args__['environmentId'] = environment_id
    __args__['name'] = name
    __args__['variableOverrides'] = variable_overrides
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:index/getEnvironment:getEnvironment', __args__, opts=opts, typ=GetEnvironmentResult).value

    return AwaitableGetEnvironmentResult(
        app_id=pulumi.get(__ret__, 'app_id'),
        description=pulumi.get(__ret__, 'description'),
        environment_id=pulumi.get(__ret__, 'environment_id'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        type=pulumi.get(__ret__, 'type'),
        variable_overrides=pulumi.get(__ret__, 'variable_overrides'))
def get_environment_output(app_id: Optional[pulumi.Input[_builtins.str]] = None,
                           environment_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           variable_overrides: Optional[pulumi.Input[Optional[Sequence[Union['GetEnvironmentVariableOverrideArgs', 'GetEnvironmentVariableOverrideArgsDict']]]]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEnvironmentResult]:
    """
    Data source for retrieving a Harness service


    :param _builtins.str app_id: The id of the application.
    :param _builtins.str environment_id: The id of the environment.
    :param _builtins.str name: The name of the environment.
    :param Sequence[Union['GetEnvironmentVariableOverrideArgs', 'GetEnvironmentVariableOverrideArgsDict']] variable_overrides: Override for a service variable
    """
    __args__ = dict()
    __args__['appId'] = app_id
    __args__['environmentId'] = environment_id
    __args__['name'] = name
    __args__['variableOverrides'] = variable_overrides
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:index/getEnvironment:getEnvironment', __args__, opts=opts, typ=GetEnvironmentResult)
    return __ret__.apply(lambda __response__: GetEnvironmentResult(
        app_id=pulumi.get(__response__, 'app_id'),
        description=pulumi.get(__response__, 'description'),
        environment_id=pulumi.get(__response__, 'environment_id'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        type=pulumi.get(__response__, 'type'),
        variable_overrides=pulumi.get(__response__, 'variable_overrides')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['OrchestratorArgs', 'Orchestrator']

@pulumi.input_type
class OrchestratorArgs:
    def __init__(__self__, *,
                 cluster_endpoint: pulumi.Input[_builtins.str],
                 k8s_connector_id: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Orchestrator resource.
        :param pulumi.Input[_builtins.str] cluster_endpoint: Endpoint of the k8s cluster being onboarded under the orchestrator
        :param pulumi.Input[_builtins.str] k8s_connector_id: ID of the Harness Kubernetes Connector Being used
        :param pulumi.Input[_builtins.str] name: Name of the Orchestrator
        :param pulumi.Input[_builtins.str] region: Region of the k8s cluster
        """
        pulumi.set(__self__, "cluster_endpoint", cluster_endpoint)
        pulumi.set(__self__, "k8s_connector_id", k8s_connector_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="clusterEndpoint")
    def cluster_endpoint(self) -> pulumi.Input[_builtins.str]:
        """
        Endpoint of the k8s cluster being onboarded under the orchestrator
        """
        return pulumi.get(self, "cluster_endpoint")

    @cluster_endpoint.setter
    def cluster_endpoint(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cluster_endpoint", value)

    @_builtins.property
    @pulumi.getter(name="k8sConnectorId")
    def k8s_connector_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the Harness Kubernetes Connector Being used
        """
        return pulumi.get(self, "k8s_connector_id")

    @k8s_connector_id.setter
    def k8s_connector_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "k8s_connector_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Orchestrator
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region of the k8s cluster
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _OrchestratorState:
    def __init__(__self__, *,
                 cluster_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 k8s_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Orchestrator resources.
        :param pulumi.Input[_builtins.str] cluster_endpoint: Endpoint of the k8s cluster being onboarded under the orchestrator
        :param pulumi.Input[_builtins.str] k8s_connector_id: ID of the Harness Kubernetes Connector Being used
        :param pulumi.Input[_builtins.str] name: Name of the Orchestrator
        :param pulumi.Input[_builtins.str] region: Region of the k8s cluster
        """
        if cluster_endpoint is not None:
            pulumi.set(__self__, "cluster_endpoint", cluster_endpoint)
        if k8s_connector_id is not None:
            pulumi.set(__self__, "k8s_connector_id", k8s_connector_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="clusterEndpoint")
    def cluster_endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Endpoint of the k8s cluster being onboarded under the orchestrator
        """
        return pulumi.get(self, "cluster_endpoint")

    @cluster_endpoint.setter
    def cluster_endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_endpoint", value)

    @_builtins.property
    @pulumi.getter(name="k8sConnectorId")
    def k8s_connector_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the Harness Kubernetes Connector Being used
        """
        return pulumi.get(self, "k8s_connector_id")

    @k8s_connector_id.setter
    def k8s_connector_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "k8s_connector_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Orchestrator
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region of the k8s cluster
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.type_token("harness:cluster/orchestrator:Orchestrator")
class Orchestrator(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 k8s_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Create a Orchestrator resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_endpoint: Endpoint of the k8s cluster being onboarded under the orchestrator
        :param pulumi.Input[_builtins.str] k8s_connector_id: ID of the Harness Kubernetes Connector Being used
        :param pulumi.Input[_builtins.str] name: Name of the Orchestrator
        :param pulumi.Input[_builtins.str] region: Region of the k8s cluster
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OrchestratorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Orchestrator resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param OrchestratorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OrchestratorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 k8s_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OrchestratorArgs.__new__(OrchestratorArgs)

            if cluster_endpoint is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_endpoint'")
            __props__.__dict__["cluster_endpoint"] = cluster_endpoint
            if k8s_connector_id is None and not opts.urn:
                raise TypeError("Missing required property 'k8s_connector_id'")
            __props__.__dict__["k8s_connector_id"] = k8s_connector_id
            __props__.__dict__["name"] = name
            __props__.__dict__["region"] = region
        super(Orchestrator, __self__).__init__(
            'harness:cluster/orchestrator:Orchestrator',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
            k8s_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None) -> 'Orchestrator':
        """
        Get an existing Orchestrator resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_endpoint: Endpoint of the k8s cluster being onboarded under the orchestrator
        :param pulumi.Input[_builtins.str] k8s_connector_id: ID of the Harness Kubernetes Connector Being used
        :param pulumi.Input[_builtins.str] name: Name of the Orchestrator
        :param pulumi.Input[_builtins.str] region: Region of the k8s cluster
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OrchestratorState.__new__(_OrchestratorState)

        __props__.__dict__["cluster_endpoint"] = cluster_endpoint
        __props__.__dict__["k8s_connector_id"] = k8s_connector_id
        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        return Orchestrator(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clusterEndpoint")
    def cluster_endpoint(self) -> pulumi.Output[_builtins.str]:
        """
        Endpoint of the k8s cluster being onboarded under the orchestrator
        """
        return pulumi.get(self, "cluster_endpoint")

    @_builtins.property
    @pulumi.getter(name="k8sConnectorId")
    def k8s_connector_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the Harness Kubernetes Connector Being used
        """
        return pulumi.get(self, "k8s_connector_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Orchestrator
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Region of the k8s cluster
        """
        return pulumi.get(self, "region")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ResourceGroupArgs', 'ResourceGroup']

@pulumi.input_type
class ResourceGroupArgs:
    def __init__(__self__, *,
                 account_id: pulumi.Input[_builtins.str],
                 identifier: pulumi.Input[_builtins.str],
                 allowed_scope_levels: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 color: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 included_scopes: Optional[pulumi.Input[Sequence[pulumi.Input['ResourceGroupIncludedScopeArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_filters: Optional[pulumi.Input[Sequence[pulumi.Input['ResourceGroupResourceFilterArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a ResourceGroup resource.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier of the account
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_scope_levels: The scope levels at which this resource group can be used
        :param pulumi.Input[_builtins.str] color: Color of the environment.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['ResourceGroupIncludedScopeArgs']]] included_scopes: Included scopes; default selected based on resource group scope if not specified.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input['ResourceGroupResourceFilterArgs']]] resource_filters: Contains resource filter for a resource group
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "identifier", identifier)
        if allowed_scope_levels is not None:
            pulumi.set(__self__, "allowed_scope_levels", allowed_scope_levels)
        if color is not None:
            pulumi.set(__self__, "color", color)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if included_scopes is not None:
            pulumi.set(__self__, "included_scopes", included_scopes)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if resource_filters is not None:
            pulumi.set(__self__, "resource_filters", resource_filters)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Input[_builtins.str]:
        """
        Account Identifier of the account
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="allowedScopeLevels")
    def allowed_scope_levels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The scope levels at which this resource group can be used
        """
        return pulumi.get(self, "allowed_scope_levels")

    @allowed_scope_levels.setter
    def allowed_scope_levels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_scope_levels", value)

    @_builtins.property
    @pulumi.getter
    def color(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Color of the environment.
        """
        return pulumi.get(self, "color")

    @color.setter
    def color(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "color", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="includedScopes")
    def included_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ResourceGroupIncludedScopeArgs']]]]:
        """
        Included scopes; default selected based on resource group scope if not specified.
        """
        return pulumi.get(self, "included_scopes")

    @included_scopes.setter
    def included_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ResourceGroupIncludedScopeArgs']]]]):
        pulumi.set(self, "included_scopes", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="resourceFilters")
    def resource_filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ResourceGroupResourceFilterArgs']]]]:
        """
        Contains resource filter for a resource group
        """
        return pulumi.get(self, "resource_filters")

    @resource_filters.setter
    def resource_filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ResourceGroupResourceFilterArgs']]]]):
        pulumi.set(self, "resource_filters", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ResourceGroupState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 allowed_scope_levels: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 color: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 included_scopes: Optional[pulumi.Input[Sequence[pulumi.Input['ResourceGroupIncludedScopeArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_filters: Optional[pulumi.Input[Sequence[pulumi.Input['ResourceGroupResourceFilterArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering ResourceGroup resources.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier of the account
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_scope_levels: The scope levels at which this resource group can be used
        :param pulumi.Input[_builtins.str] color: Color of the environment.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['ResourceGroupIncludedScopeArgs']]] included_scopes: Included scopes; default selected based on resource group scope if not specified.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input['ResourceGroupResourceFilterArgs']]] resource_filters: Contains resource filter for a resource group
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if allowed_scope_levels is not None:
            pulumi.set(__self__, "allowed_scope_levels", allowed_scope_levels)
        if color is not None:
            pulumi.set(__self__, "color", color)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if included_scopes is not None:
            pulumi.set(__self__, "included_scopes", included_scopes)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if resource_filters is not None:
            pulumi.set(__self__, "resource_filters", resource_filters)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account Identifier of the account
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="allowedScopeLevels")
    def allowed_scope_levels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The scope levels at which this resource group can be used
        """
        return pulumi.get(self, "allowed_scope_levels")

    @allowed_scope_levels.setter
    def allowed_scope_levels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_scope_levels", value)

    @_builtins.property
    @pulumi.getter
    def color(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Color of the environment.
        """
        return pulumi.get(self, "color")

    @color.setter
    def color(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "color", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="includedScopes")
    def included_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ResourceGroupIncludedScopeArgs']]]]:
        """
        Included scopes; default selected based on resource group scope if not specified.
        """
        return pulumi.get(self, "included_scopes")

    @included_scopes.setter
    def included_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ResourceGroupIncludedScopeArgs']]]]):
        pulumi.set(self, "included_scopes", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="resourceFilters")
    def resource_filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ResourceGroupResourceFilterArgs']]]]:
        """
        Contains resource filter for a resource group
        """
        return pulumi.get(self, "resource_filters")

    @resource_filters.setter
    def resource_filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ResourceGroupResourceFilterArgs']]]]):
        pulumi.set(self, "resource_filters", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("harness:platform/resourceGroup:ResourceGroup")
class ResourceGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 allowed_scope_levels: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 color: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 included_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ResourceGroupIncludedScopeArgs', 'ResourceGroupIncludedScopeArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_filters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ResourceGroupResourceFilterArgs', 'ResourceGroupResourceFilterArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for creating a Harness Resource Group

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.platform.ResourceGroup("test",
            identifier="identifier",
            name="name",
            description="test",
            tags=["foo:bar"],
            account_id="account_id",
            allowed_scope_levels=["account"],
            included_scopes=[{
                "filter": "EXCLUDING_CHILD_SCOPES",
                "account_id": "account_id",
            }],
            resource_filters=[{
                "include_all_resources": False,
                "resources": [{
                    "resource_type": "CONNECTOR",
                    "attribute_filters": [{
                        "attribute_name": "category",
                        "attribute_values": ["CLOUD_COST"],
                    }],
                }],
            }])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level resource group

        ```sh
        $ pulumi import harness:platform/resourceGroup:ResourceGroup example <resource_group_id>
        ```

        Import org level resource group

        ```sh
        $ pulumi import harness:platform/resourceGroup:ResourceGroup example <ord_id>/<resource_group_id>
        ```

        Import project level resource group

        ```sh
        $ pulumi import harness:platform/resourceGroup:ResourceGroup example <org_id>/<project_id>/<resource_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier of the account
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_scope_levels: The scope levels at which this resource group can be used
        :param pulumi.Input[_builtins.str] color: Color of the environment.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ResourceGroupIncludedScopeArgs', 'ResourceGroupIncludedScopeArgsDict']]]] included_scopes: Included scopes; default selected based on resource group scope if not specified.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ResourceGroupResourceFilterArgs', 'ResourceGroupResourceFilterArgsDict']]]] resource_filters: Contains resource filter for a resource group
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ResourceGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness Resource Group

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.platform.ResourceGroup("test",
            identifier="identifier",
            name="name",
            description="test",
            tags=["foo:bar"],
            account_id="account_id",
            allowed_scope_levels=["account"],
            included_scopes=[{
                "filter": "EXCLUDING_CHILD_SCOPES",
                "account_id": "account_id",
            }],
            resource_filters=[{
                "include_all_resources": False,
                "resources": [{
                    "resource_type": "CONNECTOR",
                    "attribute_filters": [{
                        "attribute_name": "category",
                        "attribute_values": ["CLOUD_COST"],
                    }],
                }],
            }])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level resource group

        ```sh
        $ pulumi import harness:platform/resourceGroup:ResourceGroup example <resource_group_id>
        ```

        Import org level resource group

        ```sh
        $ pulumi import harness:platform/resourceGroup:ResourceGroup example <ord_id>/<resource_group_id>
        ```

        Import project level resource group

        ```sh
        $ pulumi import harness:platform/resourceGroup:ResourceGroup example <org_id>/<project_id>/<resource_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param ResourceGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ResourceGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 allowed_scope_levels: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 color: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 included_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ResourceGroupIncludedScopeArgs', 'ResourceGroupIncludedScopeArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_filters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ResourceGroupResourceFilterArgs', 'ResourceGroupResourceFilterArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ResourceGroupArgs.__new__(ResourceGroupArgs)

            if account_id is None and not opts.urn:
                raise TypeError("Missing required property 'account_id'")
            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["allowed_scope_levels"] = allowed_scope_levels
            __props__.__dict__["color"] = color
            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["included_scopes"] = included_scopes
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["resource_filters"] = resource_filters
            __props__.__dict__["tags"] = tags
        super(ResourceGroup, __self__).__init__(
            'harness:platform/resourceGroup:ResourceGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            allowed_scope_levels: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            color: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            included_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ResourceGroupIncludedScopeArgs', 'ResourceGroupIncludedScopeArgsDict']]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            resource_filters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ResourceGroupResourceFilterArgs', 'ResourceGroupResourceFilterArgsDict']]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'ResourceGroup':
        """
        Get an existing ResourceGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier of the account
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_scope_levels: The scope levels at which this resource group can be used
        :param pulumi.Input[_builtins.str] color: Color of the environment.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ResourceGroupIncludedScopeArgs', 'ResourceGroupIncludedScopeArgsDict']]]] included_scopes: Included scopes; default selected based on resource group scope if not specified.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ResourceGroupResourceFilterArgs', 'ResourceGroupResourceFilterArgsDict']]]] resource_filters: Contains resource filter for a resource group
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ResourceGroupState.__new__(_ResourceGroupState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["allowed_scope_levels"] = allowed_scope_levels
        __props__.__dict__["color"] = color
        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["included_scopes"] = included_scopes
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["resource_filters"] = resource_filters
        __props__.__dict__["tags"] = tags
        return ResourceGroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Account Identifier of the account
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="allowedScopeLevels")
    def allowed_scope_levels(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The scope levels at which this resource group can be used
        """
        return pulumi.get(self, "allowed_scope_levels")

    @_builtins.property
    @pulumi.getter
    def color(self) -> pulumi.Output[_builtins.str]:
        """
        Color of the environment.
        """
        return pulumi.get(self, "color")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="includedScopes")
    def included_scopes(self) -> pulumi.Output[Optional[Sequence['outputs.ResourceGroupIncludedScope']]]:
        """
        Included scopes; default selected based on resource group scope if not specified.
        """
        return pulumi.get(self, "included_scopes")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="resourceFilters")
    def resource_filters(self) -> pulumi.Output[Optional[Sequence['outputs.ResourceGroupResourceFilter']]]:
        """
        Contains resource filter for a resource group
        """
        return pulumi.get(self, "resource_filters")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetEnvironmentClustersMappingResult',
    'AwaitableGetEnvironmentClustersMappingResult',
    'get_environment_clusters_mapping',
    'get_environment_clusters_mapping_output',
]

@pulumi.output_type
class GetEnvironmentClustersMappingResult:
    """
    A collection of values returned by getEnvironmentClustersMapping.
    """
    def __init__(__self__, clusters=None, env_id=None, id=None, identifier=None, org_id=None, project_id=None, scope=None):
        if clusters and not isinstance(clusters, list):
            raise TypeError("Expected argument 'clusters' to be a list")
        pulumi.set(__self__, "clusters", clusters)
        if env_id and not isinstance(env_id, str):
            raise TypeError("Expected argument 'env_id' to be a str")
        pulumi.set(__self__, "env_id", env_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if scope and not isinstance(scope, str):
            raise TypeError("Expected argument 'scope' to be a str")
        pulumi.set(__self__, "scope", scope)

    @_builtins.property
    @pulumi.getter
    def clusters(self) -> Optional[Sequence['outputs.GetEnvironmentClustersMappingClusterResult']]:
        """
        list of cluster identifiers and names
        """
        return pulumi.get(self, "clusters")

    @_builtins.property
    @pulumi.getter(name="envId")
    def env_id(self) -> _builtins.str:
        """
        environment identifier.
        """
        return pulumi.get(self, "env_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        identifier for the cluster mapping(can be given any value).
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        org_id of the environment.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        project_id of the environment.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def scope(self) -> _builtins.str:
        """
        scope at which the environment exists in harness.
        """
        return pulumi.get(self, "scope")


class AwaitableGetEnvironmentClustersMappingResult(GetEnvironmentClustersMappingResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnvironmentClustersMappingResult(
            clusters=self.clusters,
            env_id=self.env_id,
            id=self.id,
            identifier=self.identifier,
            org_id=self.org_id,
            project_id=self.project_id,
            scope=self.scope)


def get_environment_clusters_mapping(clusters: Optional[Sequence[Union['GetEnvironmentClustersMappingClusterArgs', 'GetEnvironmentClustersMappingClusterArgsDict']]] = None,
                                     env_id: Optional[_builtins.str] = None,
                                     identifier: Optional[_builtins.str] = None,
                                     org_id: Optional[_builtins.str] = None,
                                     project_id: Optional[_builtins.str] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnvironmentClustersMappingResult:
    """
    Data source for retrieving Harness Gitops clusters mapped to Harness Environment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # data source for gitops clusters mapped to a project level env
    example = harness.platform.get_environment_clusters_mapping(identifier="mycustomidentifier",
        org_id="orgIdentifer",
        project_id="projectIdentifier",
        env_id="exampleEnvId",
        clusters=[{
            "identifier": "incluster",
            "name": "in-cluster",
            "agent_identifier": "account.gitopsagentdev",
            "scope": "ACCOUNT",
        }])
    # data source for two gitops clusters mapped to an account level env
    example2 = harness.platform.get_environment_clusters_mapping(identifier="mycustomidentifier",
        env_id="env1",
        clusters=[
            {
                "identifier": "clusterA",
                "name": "cluster-A",
                "agent_identifier": "account.gitopsagentprod",
                "scope": "ACCOUNT",
            },
            {
                "identifier": "clusterB",
                "name": "cluster-B",
                "agent_identifier": "account.gitopsagentprod",
                "scope": "ACCOUNT",
            },
        ])
    ```


    :param Sequence[Union['GetEnvironmentClustersMappingClusterArgs', 'GetEnvironmentClustersMappingClusterArgsDict']] clusters: list of cluster identifiers and names
    :param _builtins.str env_id: environment identifier.
    :param _builtins.str identifier: identifier for the cluster mapping(can be given any value).
    :param _builtins.str org_id: org_id of the environment.
    :param _builtins.str project_id: project_id of the environment.
    """
    __args__ = dict()
    __args__['clusters'] = clusters
    __args__['envId'] = env_id
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getEnvironmentClustersMapping:getEnvironmentClustersMapping', __args__, opts=opts, typ=GetEnvironmentClustersMappingResult).value

    return AwaitableGetEnvironmentClustersMappingResult(
        clusters=pulumi.get(__ret__, 'clusters'),
        env_id=pulumi.get(__ret__, 'env_id'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        scope=pulumi.get(__ret__, 'scope'))
def get_environment_clusters_mapping_output(clusters: Optional[pulumi.Input[Optional[Sequence[Union['GetEnvironmentClustersMappingClusterArgs', 'GetEnvironmentClustersMappingClusterArgsDict']]]]] = None,
                                            env_id: Optional[pulumi.Input[_builtins.str]] = None,
                                            identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                            org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEnvironmentClustersMappingResult]:
    """
    Data source for retrieving Harness Gitops clusters mapped to Harness Environment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # data source for gitops clusters mapped to a project level env
    example = harness.platform.get_environment_clusters_mapping(identifier="mycustomidentifier",
        org_id="orgIdentifer",
        project_id="projectIdentifier",
        env_id="exampleEnvId",
        clusters=[{
            "identifier": "incluster",
            "name": "in-cluster",
            "agent_identifier": "account.gitopsagentdev",
            "scope": "ACCOUNT",
        }])
    # data source for two gitops clusters mapped to an account level env
    example2 = harness.platform.get_environment_clusters_mapping(identifier="mycustomidentifier",
        env_id="env1",
        clusters=[
            {
                "identifier": "clusterA",
                "name": "cluster-A",
                "agent_identifier": "account.gitopsagentprod",
                "scope": "ACCOUNT",
            },
            {
                "identifier": "clusterB",
                "name": "cluster-B",
                "agent_identifier": "account.gitopsagentprod",
                "scope": "ACCOUNT",
            },
        ])
    ```


    :param Sequence[Union['GetEnvironmentClustersMappingClusterArgs', 'GetEnvironmentClustersMappingClusterArgsDict']] clusters: list of cluster identifiers and names
    :param _builtins.str env_id: environment identifier.
    :param _builtins.str identifier: identifier for the cluster mapping(can be given any value).
    :param _builtins.str org_id: org_id of the environment.
    :param _builtins.str project_id: project_id of the environment.
    """
    __args__ = dict()
    __args__['clusters'] = clusters
    __args__['envId'] = env_id
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getEnvironmentClustersMapping:getEnvironmentClustersMapping', __args__, opts=opts, typ=GetEnvironmentClustersMappingResult)
    return __ret__.apply(lambda __response__: GetEnvironmentClustersMappingResult(
        clusters=pulumi.get(__response__, 'clusters'),
        env_id=pulumi.get(__response__, 'env_id'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        scope=pulumi.get(__response__, 'scope')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .get_hub import *
from .get_image_registry import *
from .get_infrastructure_v2 import *
from .get_security_governance_condition import *
from .get_security_governance_rule import *
from .hub import *
from .hub_sync import *
from .image_registry import *
from .infrastructure_v2 import *
from .security_governance_condition import *
from .security_governance_rule import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IdpEnvironmentArgs', 'IdpEnvironment']

@pulumi.input_type
class IdpEnvironmentArgs:
    def __init__(__self__, *,
                 blueprint_identifier: pulumi.Input[_builtins.str],
                 blueprint_version: pulumi.Input[_builtins.str],
                 identifier: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 overrides: pulumi.Input[_builtins.str],
                 owner: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 based_on: Optional[pulumi.Input[_builtins.str]] = None,
                 inputs: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 target_state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a IdpEnvironment resource.
        :param pulumi.Input[_builtins.str] blueprint_identifier: Blueprint to base the environment on
        :param pulumi.Input[_builtins.str] blueprint_version: Version of the blueprint to base the environment on
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] overrides: Overrides for environment blueprint inputs in YAML format
        :param pulumi.Input[_builtins.str] owner: Owner of the environment
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] based_on: Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        :param pulumi.Input[_builtins.str] inputs: Additional inputs for controlling the environment in YAML format
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] target_state: target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        pulumi.set(__self__, "blueprint_identifier", blueprint_identifier)
        pulumi.set(__self__, "blueprint_version", blueprint_version)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "overrides", overrides)
        pulumi.set(__self__, "owner", owner)
        pulumi.set(__self__, "project_id", project_id)
        if based_on is not None:
            pulumi.set(__self__, "based_on", based_on)
        if inputs is not None:
            pulumi.set(__self__, "inputs", inputs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if target_state is not None:
            pulumi.set(__self__, "target_state", target_state)

    @_builtins.property
    @pulumi.getter(name="blueprintIdentifier")
    def blueprint_identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_identifier")

    @blueprint_identifier.setter
    def blueprint_identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "blueprint_identifier", value)

    @_builtins.property
    @pulumi.getter(name="blueprintVersion")
    def blueprint_version(self) -> pulumi.Input[_builtins.str]:
        """
        Version of the blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_version")

    @blueprint_version.setter
    def blueprint_version(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "blueprint_version", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def overrides(self) -> pulumi.Input[_builtins.str]:
        """
        Overrides for environment blueprint inputs in YAML format
        """
        return pulumi.get(self, "overrides")

    @overrides.setter
    def overrides(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "overrides", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> pulumi.Input[_builtins.str]:
        """
        Owner of the environment
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="basedOn")
    def based_on(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        """
        return pulumi.get(self, "based_on")

    @based_on.setter
    def based_on(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "based_on", value)

    @_builtins.property
    @pulumi.getter
    def inputs(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional inputs for controlling the environment in YAML format
        """
        return pulumi.get(self, "inputs")

    @inputs.setter
    def inputs(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "inputs", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="targetState")
    def target_state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        return pulumi.get(self, "target_state")

    @target_state.setter
    def target_state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_state", value)


@pulumi.input_type
class _IdpEnvironmentState:
    def __init__(__self__, *,
                 based_on: Optional[pulumi.Input[_builtins.str]] = None,
                 blueprint_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 blueprint_version: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 inputs: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 overrides: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 target_state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering IdpEnvironment resources.
        :param pulumi.Input[_builtins.str] based_on: Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        :param pulumi.Input[_builtins.str] blueprint_identifier: Blueprint to base the environment on
        :param pulumi.Input[_builtins.str] blueprint_version: Version of the blueprint to base the environment on
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] inputs: Additional inputs for controlling the environment in YAML format
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] overrides: Overrides for environment blueprint inputs in YAML format
        :param pulumi.Input[_builtins.str] owner: Owner of the environment
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] target_state: target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        if based_on is not None:
            pulumi.set(__self__, "based_on", based_on)
        if blueprint_identifier is not None:
            pulumi.set(__self__, "blueprint_identifier", blueprint_identifier)
        if blueprint_version is not None:
            pulumi.set(__self__, "blueprint_version", blueprint_version)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if inputs is not None:
            pulumi.set(__self__, "inputs", inputs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if overrides is not None:
            pulumi.set(__self__, "overrides", overrides)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if target_state is not None:
            pulumi.set(__self__, "target_state", target_state)

    @_builtins.property
    @pulumi.getter(name="basedOn")
    def based_on(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        """
        return pulumi.get(self, "based_on")

    @based_on.setter
    def based_on(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "based_on", value)

    @_builtins.property
    @pulumi.getter(name="blueprintIdentifier")
    def blueprint_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_identifier")

    @blueprint_identifier.setter
    def blueprint_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "blueprint_identifier", value)

    @_builtins.property
    @pulumi.getter(name="blueprintVersion")
    def blueprint_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Version of the blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_version")

    @blueprint_version.setter
    def blueprint_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "blueprint_version", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def inputs(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional inputs for controlling the environment in YAML format
        """
        return pulumi.get(self, "inputs")

    @inputs.setter
    def inputs(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "inputs", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def overrides(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Overrides for environment blueprint inputs in YAML format
        """
        return pulumi.get(self, "overrides")

    @overrides.setter
    def overrides(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "overrides", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Owner of the environment
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="targetState")
    def target_state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        return pulumi.get(self, "target_state")

    @target_state.setter
    def target_state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_state", value)


@pulumi.type_token("harness:platform/idpEnvironment:IdpEnvironment")
class IdpEnvironment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 based_on: Optional[pulumi.Input[_builtins.str]] = None,
                 blueprint_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 blueprint_version: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 inputs: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 overrides: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 target_state: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating IDP environments.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.platform.IdpEnvironment("test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="test",
            owner="group:account/_account_all_users",
            blueprint_identifier="blueprint_identifier",
            blueprint_version="v1.0.0",
            target_state="running",
            based_on="org_id.project_id/environment_identifier",
            overrides=\"\"\"config: {}
        entities: {}
        \"\"\",
            inputs="ttl: 1h30m\\n")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import environment

        ```sh
        $ pulumi import harness:platform/idpEnvironment:IdpEnvironment example <org_id>/<project_id>/<environment_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] based_on: Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        :param pulumi.Input[_builtins.str] blueprint_identifier: Blueprint to base the environment on
        :param pulumi.Input[_builtins.str] blueprint_version: Version of the blueprint to base the environment on
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] inputs: Additional inputs for controlling the environment in YAML format
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] overrides: Overrides for environment blueprint inputs in YAML format
        :param pulumi.Input[_builtins.str] owner: Owner of the environment
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] target_state: target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IdpEnvironmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating IDP environments.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.platform.IdpEnvironment("test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="test",
            owner="group:account/_account_all_users",
            blueprint_identifier="blueprint_identifier",
            blueprint_version="v1.0.0",
            target_state="running",
            based_on="org_id.project_id/environment_identifier",
            overrides=\"\"\"config: {}
        entities: {}
        \"\"\",
            inputs="ttl: 1h30m\\n")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import environment

        ```sh
        $ pulumi import harness:platform/idpEnvironment:IdpEnvironment example <org_id>/<project_id>/<environment_id>
        ```

        :param str resource_name: The name of the resource.
        :param IdpEnvironmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IdpEnvironmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 based_on: Optional[pulumi.Input[_builtins.str]] = None,
                 blueprint_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 blueprint_version: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 inputs: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 overrides: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 target_state: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IdpEnvironmentArgs.__new__(IdpEnvironmentArgs)

            __props__.__dict__["based_on"] = based_on
            if blueprint_identifier is None and not opts.urn:
                raise TypeError("Missing required property 'blueprint_identifier'")
            __props__.__dict__["blueprint_identifier"] = blueprint_identifier
            if blueprint_version is None and not opts.urn:
                raise TypeError("Missing required property 'blueprint_version'")
            __props__.__dict__["blueprint_version"] = blueprint_version
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["inputs"] = inputs
            __props__.__dict__["name"] = name
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            if overrides is None and not opts.urn:
                raise TypeError("Missing required property 'overrides'")
            __props__.__dict__["overrides"] = overrides
            if owner is None and not opts.urn:
                raise TypeError("Missing required property 'owner'")
            __props__.__dict__["owner"] = owner
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["target_state"] = target_state
        super(IdpEnvironment, __self__).__init__(
            'harness:platform/idpEnvironment:IdpEnvironment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            based_on: Optional[pulumi.Input[_builtins.str]] = None,
            blueprint_identifier: Optional[pulumi.Input[_builtins.str]] = None,
            blueprint_version: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            inputs: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            overrides: Optional[pulumi.Input[_builtins.str]] = None,
            owner: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            target_state: Optional[pulumi.Input[_builtins.str]] = None) -> 'IdpEnvironment':
        """
        Get an existing IdpEnvironment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] based_on: Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        :param pulumi.Input[_builtins.str] blueprint_identifier: Blueprint to base the environment on
        :param pulumi.Input[_builtins.str] blueprint_version: Version of the blueprint to base the environment on
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] inputs: Additional inputs for controlling the environment in YAML format
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] overrides: Overrides for environment blueprint inputs in YAML format
        :param pulumi.Input[_builtins.str] owner: Owner of the environment
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] target_state: target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IdpEnvironmentState.__new__(_IdpEnvironmentState)

        __props__.__dict__["based_on"] = based_on
        __props__.__dict__["blueprint_identifier"] = blueprint_identifier
        __props__.__dict__["blueprint_version"] = blueprint_version
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["inputs"] = inputs
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["overrides"] = overrides
        __props__.__dict__["owner"] = owner
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["target_state"] = target_state
        return IdpEnvironment(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="basedOn")
    def based_on(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        """
        return pulumi.get(self, "based_on")

    @_builtins.property
    @pulumi.getter(name="blueprintIdentifier")
    def blueprint_identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_identifier")

    @_builtins.property
    @pulumi.getter(name="blueprintVersion")
    def blueprint_version(self) -> pulumi.Output[_builtins.str]:
        """
        Version of the blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_version")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def inputs(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Additional inputs for controlling the environment in YAML format
        """
        return pulumi.get(self, "inputs")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def overrides(self) -> pulumi.Output[_builtins.str]:
        """
        Overrides for environment blueprint inputs in YAML format
        """
        return pulumi.get(self, "overrides")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> pulumi.Output[_builtins.str]:
        """
        Owner of the environment
        """
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="targetState")
    def target_state(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        return pulumi.get(self, "target_state")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AwsConnectorArgs', 'AwsConnector']

@pulumi.input_type
class AwsConnectorArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 cross_account_access: Optional[pulumi.Input['AwsConnectorCrossAccountAccessArgs']] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 equal_jitter_backoff_strategy: Optional[pulumi.Input['AwsConnectorEqualJitterBackoffStrategyArgs']] = None,
                 execute_on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
                 fixed_delay_backoff_strategy: Optional[pulumi.Input['AwsConnectorFixedDelayBackoffStrategyArgs']] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 full_jitter_backoff_strategy: Optional[pulumi.Input['AwsConnectorFullJitterBackoffStrategyArgs']] = None,
                 inherit_from_delegate: Optional[pulumi.Input['AwsConnectorInheritFromDelegateArgs']] = None,
                 irsa: Optional[pulumi.Input['AwsConnectorIrsaArgs']] = None,
                 manual: Optional[pulumi.Input['AwsConnectorManualArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 oidc_authentication: Optional[pulumi.Input['AwsConnectorOidcAuthenticationArgs']] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a AwsConnector resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input['AwsConnectorCrossAccountAccessArgs'] cross_account_access: Select this option if you want to use one AWS account for the connection, but you want to deploy or build in a different AWS account. In this scenario, the AWS account used for AWS access in Credentials will assume the IAM role you specify in Cross-account role ARN setting. This option uses the AWS Security Token Service (STS) feature.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input['AwsConnectorEqualJitterBackoffStrategyArgs'] equal_jitter_backoff_strategy: Equal Jitter BackOff Strategy.
        :param pulumi.Input[_builtins.bool] execute_on_delegate: Enable this flag to execute on Delegate
        :param pulumi.Input['AwsConnectorFixedDelayBackoffStrategyArgs'] fixed_delay_backoff_strategy: Fixed Delay BackOff Strategy.
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of connector
        :param pulumi.Input['AwsConnectorFullJitterBackoffStrategyArgs'] full_jitter_backoff_strategy: Full Jitter BackOff Strategy.
        :param pulumi.Input['AwsConnectorInheritFromDelegateArgs'] inherit_from_delegate: Inherit credentials from the delegate.
        :param pulumi.Input['AwsConnectorIrsaArgs'] irsa: Use IAM role for service accounts.
        :param pulumi.Input['AwsConnectorManualArgs'] manual: Use IAM role for service accounts.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input['AwsConnectorOidcAuthenticationArgs'] oidc_authentication: Authentication using harness oidc.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        pulumi.set(__self__, "identifier", identifier)
        if cross_account_access is not None:
            pulumi.set(__self__, "cross_account_access", cross_account_access)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if equal_jitter_backoff_strategy is not None:
            pulumi.set(__self__, "equal_jitter_backoff_strategy", equal_jitter_backoff_strategy)
        if execute_on_delegate is not None:
            pulumi.set(__self__, "execute_on_delegate", execute_on_delegate)
        if fixed_delay_backoff_strategy is not None:
            pulumi.set(__self__, "fixed_delay_backoff_strategy", fixed_delay_backoff_strategy)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if full_jitter_backoff_strategy is not None:
            pulumi.set(__self__, "full_jitter_backoff_strategy", full_jitter_backoff_strategy)
        if inherit_from_delegate is not None:
            pulumi.set(__self__, "inherit_from_delegate", inherit_from_delegate)
        if irsa is not None:
            pulumi.set(__self__, "irsa", irsa)
        if manual is not None:
            pulumi.set(__self__, "manual", manual)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if oidc_authentication is not None:
            pulumi.set(__self__, "oidc_authentication", oidc_authentication)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="crossAccountAccess")
    def cross_account_access(self) -> Optional[pulumi.Input['AwsConnectorCrossAccountAccessArgs']]:
        """
        Select this option if you want to use one AWS account for the connection, but you want to deploy or build in a different AWS account. In this scenario, the AWS account used for AWS access in Credentials will assume the IAM role you specify in Cross-account role ARN setting. This option uses the AWS Security Token Service (STS) feature.
        """
        return pulumi.get(self, "cross_account_access")

    @cross_account_access.setter
    def cross_account_access(self, value: Optional[pulumi.Input['AwsConnectorCrossAccountAccessArgs']]):
        pulumi.set(self, "cross_account_access", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="equalJitterBackoffStrategy")
    def equal_jitter_backoff_strategy(self) -> Optional[pulumi.Input['AwsConnectorEqualJitterBackoffStrategyArgs']]:
        """
        Equal Jitter BackOff Strategy.
        """
        return pulumi.get(self, "equal_jitter_backoff_strategy")

    @equal_jitter_backoff_strategy.setter
    def equal_jitter_backoff_strategy(self, value: Optional[pulumi.Input['AwsConnectorEqualJitterBackoffStrategyArgs']]):
        pulumi.set(self, "equal_jitter_backoff_strategy", value)

    @_builtins.property
    @pulumi.getter(name="executeOnDelegate")
    def execute_on_delegate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable this flag to execute on Delegate
        """
        return pulumi.get(self, "execute_on_delegate")

    @execute_on_delegate.setter
    def execute_on_delegate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "execute_on_delegate", value)

    @_builtins.property
    @pulumi.getter(name="fixedDelayBackoffStrategy")
    def fixed_delay_backoff_strategy(self) -> Optional[pulumi.Input['AwsConnectorFixedDelayBackoffStrategyArgs']]:
        """
        Fixed Delay BackOff Strategy.
        """
        return pulumi.get(self, "fixed_delay_backoff_strategy")

    @fixed_delay_backoff_strategy.setter
    def fixed_delay_backoff_strategy(self, value: Optional[pulumi.Input['AwsConnectorFixedDelayBackoffStrategyArgs']]):
        pulumi.set(self, "fixed_delay_backoff_strategy", value)

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable this flag for force deletion of connector
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @_builtins.property
    @pulumi.getter(name="fullJitterBackoffStrategy")
    def full_jitter_backoff_strategy(self) -> Optional[pulumi.Input['AwsConnectorFullJitterBackoffStrategyArgs']]:
        """
        Full Jitter BackOff Strategy.
        """
        return pulumi.get(self, "full_jitter_backoff_strategy")

    @full_jitter_backoff_strategy.setter
    def full_jitter_backoff_strategy(self, value: Optional[pulumi.Input['AwsConnectorFullJitterBackoffStrategyArgs']]):
        pulumi.set(self, "full_jitter_backoff_strategy", value)

    @_builtins.property
    @pulumi.getter(name="inheritFromDelegate")
    def inherit_from_delegate(self) -> Optional[pulumi.Input['AwsConnectorInheritFromDelegateArgs']]:
        """
        Inherit credentials from the delegate.
        """
        return pulumi.get(self, "inherit_from_delegate")

    @inherit_from_delegate.setter
    def inherit_from_delegate(self, value: Optional[pulumi.Input['AwsConnectorInheritFromDelegateArgs']]):
        pulumi.set(self, "inherit_from_delegate", value)

    @_builtins.property
    @pulumi.getter
    def irsa(self) -> Optional[pulumi.Input['AwsConnectorIrsaArgs']]:
        """
        Use IAM role for service accounts.
        """
        return pulumi.get(self, "irsa")

    @irsa.setter
    def irsa(self, value: Optional[pulumi.Input['AwsConnectorIrsaArgs']]):
        pulumi.set(self, "irsa", value)

    @_builtins.property
    @pulumi.getter
    def manual(self) -> Optional[pulumi.Input['AwsConnectorManualArgs']]:
        """
        Use IAM role for service accounts.
        """
        return pulumi.get(self, "manual")

    @manual.setter
    def manual(self, value: Optional[pulumi.Input['AwsConnectorManualArgs']]):
        pulumi.set(self, "manual", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="oidcAuthentication")
    def oidc_authentication(self) -> Optional[pulumi.Input['AwsConnectorOidcAuthenticationArgs']]:
        """
        Authentication using harness oidc.
        """
        return pulumi.get(self, "oidc_authentication")

    @oidc_authentication.setter
    def oidc_authentication(self, value: Optional[pulumi.Input['AwsConnectorOidcAuthenticationArgs']]):
        pulumi.set(self, "oidc_authentication", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _AwsConnectorState:
    def __init__(__self__, *,
                 cross_account_access: Optional[pulumi.Input['AwsConnectorCrossAccountAccessArgs']] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 equal_jitter_backoff_strategy: Optional[pulumi.Input['AwsConnectorEqualJitterBackoffStrategyArgs']] = None,
                 execute_on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
                 fixed_delay_backoff_strategy: Optional[pulumi.Input['AwsConnectorFixedDelayBackoffStrategyArgs']] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 full_jitter_backoff_strategy: Optional[pulumi.Input['AwsConnectorFullJitterBackoffStrategyArgs']] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 inherit_from_delegate: Optional[pulumi.Input['AwsConnectorInheritFromDelegateArgs']] = None,
                 irsa: Optional[pulumi.Input['AwsConnectorIrsaArgs']] = None,
                 manual: Optional[pulumi.Input['AwsConnectorManualArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 oidc_authentication: Optional[pulumi.Input['AwsConnectorOidcAuthenticationArgs']] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering AwsConnector resources.
        :param pulumi.Input['AwsConnectorCrossAccountAccessArgs'] cross_account_access: Select this option if you want to use one AWS account for the connection, but you want to deploy or build in a different AWS account. In this scenario, the AWS account used for AWS access in Credentials will assume the IAM role you specify in Cross-account role ARN setting. This option uses the AWS Security Token Service (STS) feature.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input['AwsConnectorEqualJitterBackoffStrategyArgs'] equal_jitter_backoff_strategy: Equal Jitter BackOff Strategy.
        :param pulumi.Input[_builtins.bool] execute_on_delegate: Enable this flag to execute on Delegate
        :param pulumi.Input['AwsConnectorFixedDelayBackoffStrategyArgs'] fixed_delay_backoff_strategy: Fixed Delay BackOff Strategy.
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of connector
        :param pulumi.Input['AwsConnectorFullJitterBackoffStrategyArgs'] full_jitter_backoff_strategy: Full Jitter BackOff Strategy.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input['AwsConnectorInheritFromDelegateArgs'] inherit_from_delegate: Inherit credentials from the delegate.
        :param pulumi.Input['AwsConnectorIrsaArgs'] irsa: Use IAM role for service accounts.
        :param pulumi.Input['AwsConnectorManualArgs'] manual: Use IAM role for service accounts.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input['AwsConnectorOidcAuthenticationArgs'] oidc_authentication: Authentication using harness oidc.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        if cross_account_access is not None:
            pulumi.set(__self__, "cross_account_access", cross_account_access)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if equal_jitter_backoff_strategy is not None:
            pulumi.set(__self__, "equal_jitter_backoff_strategy", equal_jitter_backoff_strategy)
        if execute_on_delegate is not None:
            pulumi.set(__self__, "execute_on_delegate", execute_on_delegate)
        if fixed_delay_backoff_strategy is not None:
            pulumi.set(__self__, "fixed_delay_backoff_strategy", fixed_delay_backoff_strategy)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if full_jitter_backoff_strategy is not None:
            pulumi.set(__self__, "full_jitter_backoff_strategy", full_jitter_backoff_strategy)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if inherit_from_delegate is not None:
            pulumi.set(__self__, "inherit_from_delegate", inherit_from_delegate)
        if irsa is not None:
            pulumi.set(__self__, "irsa", irsa)
        if manual is not None:
            pulumi.set(__self__, "manual", manual)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if oidc_authentication is not None:
            pulumi.set(__self__, "oidc_authentication", oidc_authentication)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="crossAccountAccess")
    def cross_account_access(self) -> Optional[pulumi.Input['AwsConnectorCrossAccountAccessArgs']]:
        """
        Select this option if you want to use one AWS account for the connection, but you want to deploy or build in a different AWS account. In this scenario, the AWS account used for AWS access in Credentials will assume the IAM role you specify in Cross-account role ARN setting. This option uses the AWS Security Token Service (STS) feature.
        """
        return pulumi.get(self, "cross_account_access")

    @cross_account_access.setter
    def cross_account_access(self, value: Optional[pulumi.Input['AwsConnectorCrossAccountAccessArgs']]):
        pulumi.set(self, "cross_account_access", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="equalJitterBackoffStrategy")
    def equal_jitter_backoff_strategy(self) -> Optional[pulumi.Input['AwsConnectorEqualJitterBackoffStrategyArgs']]:
        """
        Equal Jitter BackOff Strategy.
        """
        return pulumi.get(self, "equal_jitter_backoff_strategy")

    @equal_jitter_backoff_strategy.setter
    def equal_jitter_backoff_strategy(self, value: Optional[pulumi.Input['AwsConnectorEqualJitterBackoffStrategyArgs']]):
        pulumi.set(self, "equal_jitter_backoff_strategy", value)

    @_builtins.property
    @pulumi.getter(name="executeOnDelegate")
    def execute_on_delegate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable this flag to execute on Delegate
        """
        return pulumi.get(self, "execute_on_delegate")

    @execute_on_delegate.setter
    def execute_on_delegate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "execute_on_delegate", value)

    @_builtins.property
    @pulumi.getter(name="fixedDelayBackoffStrategy")
    def fixed_delay_backoff_strategy(self) -> Optional[pulumi.Input['AwsConnectorFixedDelayBackoffStrategyArgs']]:
        """
        Fixed Delay BackOff Strategy.
        """
        return pulumi.get(self, "fixed_delay_backoff_strategy")

    @fixed_delay_backoff_strategy.setter
    def fixed_delay_backoff_strategy(self, value: Optional[pulumi.Input['AwsConnectorFixedDelayBackoffStrategyArgs']]):
        pulumi.set(self, "fixed_delay_backoff_strategy", value)

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable this flag for force deletion of connector
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @_builtins.property
    @pulumi.getter(name="fullJitterBackoffStrategy")
    def full_jitter_backoff_strategy(self) -> Optional[pulumi.Input['AwsConnectorFullJitterBackoffStrategyArgs']]:
        """
        Full Jitter BackOff Strategy.
        """
        return pulumi.get(self, "full_jitter_backoff_strategy")

    @full_jitter_backoff_strategy.setter
    def full_jitter_backoff_strategy(self, value: Optional[pulumi.Input['AwsConnectorFullJitterBackoffStrategyArgs']]):
        pulumi.set(self, "full_jitter_backoff_strategy", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="inheritFromDelegate")
    def inherit_from_delegate(self) -> Optional[pulumi.Input['AwsConnectorInheritFromDelegateArgs']]:
        """
        Inherit credentials from the delegate.
        """
        return pulumi.get(self, "inherit_from_delegate")

    @inherit_from_delegate.setter
    def inherit_from_delegate(self, value: Optional[pulumi.Input['AwsConnectorInheritFromDelegateArgs']]):
        pulumi.set(self, "inherit_from_delegate", value)

    @_builtins.property
    @pulumi.getter
    def irsa(self) -> Optional[pulumi.Input['AwsConnectorIrsaArgs']]:
        """
        Use IAM role for service accounts.
        """
        return pulumi.get(self, "irsa")

    @irsa.setter
    def irsa(self, value: Optional[pulumi.Input['AwsConnectorIrsaArgs']]):
        pulumi.set(self, "irsa", value)

    @_builtins.property
    @pulumi.getter
    def manual(self) -> Optional[pulumi.Input['AwsConnectorManualArgs']]:
        """
        Use IAM role for service accounts.
        """
        return pulumi.get(self, "manual")

    @manual.setter
    def manual(self, value: Optional[pulumi.Input['AwsConnectorManualArgs']]):
        pulumi.set(self, "manual", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="oidcAuthentication")
    def oidc_authentication(self) -> Optional[pulumi.Input['AwsConnectorOidcAuthenticationArgs']]:
        """
        Authentication using harness oidc.
        """
        return pulumi.get(self, "oidc_authentication")

    @oidc_authentication.setter
    def oidc_authentication(self, value: Optional[pulumi.Input['AwsConnectorOidcAuthenticationArgs']]):
        pulumi.set(self, "oidc_authentication", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("harness:platform/awsConnector:AwsConnector")
class AwsConnector(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cross_account_access: Optional[pulumi.Input[Union['AwsConnectorCrossAccountAccessArgs', 'AwsConnectorCrossAccountAccessArgsDict']]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 equal_jitter_backoff_strategy: Optional[pulumi.Input[Union['AwsConnectorEqualJitterBackoffStrategyArgs', 'AwsConnectorEqualJitterBackoffStrategyArgsDict']]] = None,
                 execute_on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
                 fixed_delay_backoff_strategy: Optional[pulumi.Input[Union['AwsConnectorFixedDelayBackoffStrategyArgs', 'AwsConnectorFixedDelayBackoffStrategyArgsDict']]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 full_jitter_backoff_strategy: Optional[pulumi.Input[Union['AwsConnectorFullJitterBackoffStrategyArgs', 'AwsConnectorFullJitterBackoffStrategyArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 inherit_from_delegate: Optional[pulumi.Input[Union['AwsConnectorInheritFromDelegateArgs', 'AwsConnectorInheritFromDelegateArgsDict']]] = None,
                 irsa: Optional[pulumi.Input[Union['AwsConnectorIrsaArgs', 'AwsConnectorIrsaArgsDict']]] = None,
                 manual: Optional[pulumi.Input[Union['AwsConnectorManualArgs', 'AwsConnectorManualArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 oidc_authentication: Optional[pulumi.Input[Union['AwsConnectorOidcAuthenticationArgs', 'AwsConnectorOidcAuthenticationArgsDict']]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for creating an AWS connector.

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level aws connector

        ```sh
        $ pulumi import harness:platform/awsConnector:AwsConnector example <connector_id>
        ```

        Import organization level aws connector

        ```sh
        $ pulumi import harness:platform/awsConnector:AwsConnector example <organization_id>/<connector_id>
        ```

        Import project level aws connector

        ```sh
        $ pulumi import harness:platform/awsConnector:AwsConnector example <organization_id>/<project_id>/<connector_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['AwsConnectorCrossAccountAccessArgs', 'AwsConnectorCrossAccountAccessArgsDict']] cross_account_access: Select this option if you want to use one AWS account for the connection, but you want to deploy or build in a different AWS account. In this scenario, the AWS account used for AWS access in Credentials will assume the IAM role you specify in Cross-account role ARN setting. This option uses the AWS Security Token Service (STS) feature.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Union['AwsConnectorEqualJitterBackoffStrategyArgs', 'AwsConnectorEqualJitterBackoffStrategyArgsDict']] equal_jitter_backoff_strategy: Equal Jitter BackOff Strategy.
        :param pulumi.Input[_builtins.bool] execute_on_delegate: Enable this flag to execute on Delegate
        :param pulumi.Input[Union['AwsConnectorFixedDelayBackoffStrategyArgs', 'AwsConnectorFixedDelayBackoffStrategyArgsDict']] fixed_delay_backoff_strategy: Fixed Delay BackOff Strategy.
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of connector
        :param pulumi.Input[Union['AwsConnectorFullJitterBackoffStrategyArgs', 'AwsConnectorFullJitterBackoffStrategyArgsDict']] full_jitter_backoff_strategy: Full Jitter BackOff Strategy.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[Union['AwsConnectorInheritFromDelegateArgs', 'AwsConnectorInheritFromDelegateArgsDict']] inherit_from_delegate: Inherit credentials from the delegate.
        :param pulumi.Input[Union['AwsConnectorIrsaArgs', 'AwsConnectorIrsaArgsDict']] irsa: Use IAM role for service accounts.
        :param pulumi.Input[Union['AwsConnectorManualArgs', 'AwsConnectorManualArgsDict']] manual: Use IAM role for service accounts.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Union['AwsConnectorOidcAuthenticationArgs', 'AwsConnectorOidcAuthenticationArgsDict']] oidc_authentication: Authentication using harness oidc.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AwsConnectorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating an AWS connector.

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level aws connector

        ```sh
        $ pulumi import harness:platform/awsConnector:AwsConnector example <connector_id>
        ```

        Import organization level aws connector

        ```sh
        $ pulumi import harness:platform/awsConnector:AwsConnector example <organization_id>/<connector_id>
        ```

        Import project level aws connector

        ```sh
        $ pulumi import harness:platform/awsConnector:AwsConnector example <organization_id>/<project_id>/<connector_id>
        ```

        :param str resource_name: The name of the resource.
        :param AwsConnectorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AwsConnectorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cross_account_access: Optional[pulumi.Input[Union['AwsConnectorCrossAccountAccessArgs', 'AwsConnectorCrossAccountAccessArgsDict']]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 equal_jitter_backoff_strategy: Optional[pulumi.Input[Union['AwsConnectorEqualJitterBackoffStrategyArgs', 'AwsConnectorEqualJitterBackoffStrategyArgsDict']]] = None,
                 execute_on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
                 fixed_delay_backoff_strategy: Optional[pulumi.Input[Union['AwsConnectorFixedDelayBackoffStrategyArgs', 'AwsConnectorFixedDelayBackoffStrategyArgsDict']]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 full_jitter_backoff_strategy: Optional[pulumi.Input[Union['AwsConnectorFullJitterBackoffStrategyArgs', 'AwsConnectorFullJitterBackoffStrategyArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 inherit_from_delegate: Optional[pulumi.Input[Union['AwsConnectorInheritFromDelegateArgs', 'AwsConnectorInheritFromDelegateArgsDict']]] = None,
                 irsa: Optional[pulumi.Input[Union['AwsConnectorIrsaArgs', 'AwsConnectorIrsaArgsDict']]] = None,
                 manual: Optional[pulumi.Input[Union['AwsConnectorManualArgs', 'AwsConnectorManualArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 oidc_authentication: Optional[pulumi.Input[Union['AwsConnectorOidcAuthenticationArgs', 'AwsConnectorOidcAuthenticationArgsDict']]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AwsConnectorArgs.__new__(AwsConnectorArgs)

            __props__.__dict__["cross_account_access"] = cross_account_access
            __props__.__dict__["description"] = description
            __props__.__dict__["equal_jitter_backoff_strategy"] = equal_jitter_backoff_strategy
            __props__.__dict__["execute_on_delegate"] = execute_on_delegate
            __props__.__dict__["fixed_delay_backoff_strategy"] = fixed_delay_backoff_strategy
            __props__.__dict__["force_delete"] = force_delete
            __props__.__dict__["full_jitter_backoff_strategy"] = full_jitter_backoff_strategy
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["inherit_from_delegate"] = inherit_from_delegate
            __props__.__dict__["irsa"] = irsa
            __props__.__dict__["manual"] = manual
            __props__.__dict__["name"] = name
            __props__.__dict__["oidc_authentication"] = oidc_authentication
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
        super(AwsConnector, __self__).__init__(
            'harness:platform/awsConnector:AwsConnector',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cross_account_access: Optional[pulumi.Input[Union['AwsConnectorCrossAccountAccessArgs', 'AwsConnectorCrossAccountAccessArgsDict']]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            equal_jitter_backoff_strategy: Optional[pulumi.Input[Union['AwsConnectorEqualJitterBackoffStrategyArgs', 'AwsConnectorEqualJitterBackoffStrategyArgsDict']]] = None,
            execute_on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
            fixed_delay_backoff_strategy: Optional[pulumi.Input[Union['AwsConnectorFixedDelayBackoffStrategyArgs', 'AwsConnectorFixedDelayBackoffStrategyArgsDict']]] = None,
            force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
            full_jitter_backoff_strategy: Optional[pulumi.Input[Union['AwsConnectorFullJitterBackoffStrategyArgs', 'AwsConnectorFullJitterBackoffStrategyArgsDict']]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            inherit_from_delegate: Optional[pulumi.Input[Union['AwsConnectorInheritFromDelegateArgs', 'AwsConnectorInheritFromDelegateArgsDict']]] = None,
            irsa: Optional[pulumi.Input[Union['AwsConnectorIrsaArgs', 'AwsConnectorIrsaArgsDict']]] = None,
            manual: Optional[pulumi.Input[Union['AwsConnectorManualArgs', 'AwsConnectorManualArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            oidc_authentication: Optional[pulumi.Input[Union['AwsConnectorOidcAuthenticationArgs', 'AwsConnectorOidcAuthenticationArgsDict']]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'AwsConnector':
        """
        Get an existing AwsConnector resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['AwsConnectorCrossAccountAccessArgs', 'AwsConnectorCrossAccountAccessArgsDict']] cross_account_access: Select this option if you want to use one AWS account for the connection, but you want to deploy or build in a different AWS account. In this scenario, the AWS account used for AWS access in Credentials will assume the IAM role you specify in Cross-account role ARN setting. This option uses the AWS Security Token Service (STS) feature.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Union['AwsConnectorEqualJitterBackoffStrategyArgs', 'AwsConnectorEqualJitterBackoffStrategyArgsDict']] equal_jitter_backoff_strategy: Equal Jitter BackOff Strategy.
        :param pulumi.Input[_builtins.bool] execute_on_delegate: Enable this flag to execute on Delegate
        :param pulumi.Input[Union['AwsConnectorFixedDelayBackoffStrategyArgs', 'AwsConnectorFixedDelayBackoffStrategyArgsDict']] fixed_delay_backoff_strategy: Fixed Delay BackOff Strategy.
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of connector
        :param pulumi.Input[Union['AwsConnectorFullJitterBackoffStrategyArgs', 'AwsConnectorFullJitterBackoffStrategyArgsDict']] full_jitter_backoff_strategy: Full Jitter BackOff Strategy.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[Union['AwsConnectorInheritFromDelegateArgs', 'AwsConnectorInheritFromDelegateArgsDict']] inherit_from_delegate: Inherit credentials from the delegate.
        :param pulumi.Input[Union['AwsConnectorIrsaArgs', 'AwsConnectorIrsaArgsDict']] irsa: Use IAM role for service accounts.
        :param pulumi.Input[Union['AwsConnectorManualArgs', 'AwsConnectorManualArgsDict']] manual: Use IAM role for service accounts.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Union['AwsConnectorOidcAuthenticationArgs', 'AwsConnectorOidcAuthenticationArgsDict']] oidc_authentication: Authentication using harness oidc.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AwsConnectorState.__new__(_AwsConnectorState)

        __props__.__dict__["cross_account_access"] = cross_account_access
        __props__.__dict__["description"] = description
        __props__.__dict__["equal_jitter_backoff_strategy"] = equal_jitter_backoff_strategy
        __props__.__dict__["execute_on_delegate"] = execute_on_delegate
        __props__.__dict__["fixed_delay_backoff_strategy"] = fixed_delay_backoff_strategy
        __props__.__dict__["force_delete"] = force_delete
        __props__.__dict__["full_jitter_backoff_strategy"] = full_jitter_backoff_strategy
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["inherit_from_delegate"] = inherit_from_delegate
        __props__.__dict__["irsa"] = irsa
        __props__.__dict__["manual"] = manual
        __props__.__dict__["name"] = name
        __props__.__dict__["oidc_authentication"] = oidc_authentication
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        return AwsConnector(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="crossAccountAccess")
    def cross_account_access(self) -> pulumi.Output[Optional['outputs.AwsConnectorCrossAccountAccess']]:
        """
        Select this option if you want to use one AWS account for the connection, but you want to deploy or build in a different AWS account. In this scenario, the AWS account used for AWS access in Credentials will assume the IAM role you specify in Cross-account role ARN setting. This option uses the AWS Security Token Service (STS) feature.
        """
        return pulumi.get(self, "cross_account_access")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="equalJitterBackoffStrategy")
    def equal_jitter_backoff_strategy(self) -> pulumi.Output[Optional['outputs.AwsConnectorEqualJitterBackoffStrategy']]:
        """
        Equal Jitter BackOff Strategy.
        """
        return pulumi.get(self, "equal_jitter_backoff_strategy")

    @_builtins.property
    @pulumi.getter(name="executeOnDelegate")
    def execute_on_delegate(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Enable this flag to execute on Delegate
        """
        return pulumi.get(self, "execute_on_delegate")

    @_builtins.property
    @pulumi.getter(name="fixedDelayBackoffStrategy")
    def fixed_delay_backoff_strategy(self) -> pulumi.Output[Optional['outputs.AwsConnectorFixedDelayBackoffStrategy']]:
        """
        Fixed Delay BackOff Strategy.
        """
        return pulumi.get(self, "fixed_delay_backoff_strategy")

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable this flag for force deletion of connector
        """
        return pulumi.get(self, "force_delete")

    @_builtins.property
    @pulumi.getter(name="fullJitterBackoffStrategy")
    def full_jitter_backoff_strategy(self) -> pulumi.Output[Optional['outputs.AwsConnectorFullJitterBackoffStrategy']]:
        """
        Full Jitter BackOff Strategy.
        """
        return pulumi.get(self, "full_jitter_backoff_strategy")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="inheritFromDelegate")
    def inherit_from_delegate(self) -> pulumi.Output[Optional['outputs.AwsConnectorInheritFromDelegate']]:
        """
        Inherit credentials from the delegate.
        """
        return pulumi.get(self, "inherit_from_delegate")

    @_builtins.property
    @pulumi.getter
    def irsa(self) -> pulumi.Output[Optional['outputs.AwsConnectorIrsa']]:
        """
        Use IAM role for service accounts.
        """
        return pulumi.get(self, "irsa")

    @_builtins.property
    @pulumi.getter
    def manual(self) -> pulumi.Output[Optional['outputs.AwsConnectorManual']]:
        """
        Use IAM role for service accounts.
        """
        return pulumi.get(self, "manual")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="oidcAuthentication")
    def oidc_authentication(self) -> pulumi.Output[Optional['outputs.AwsConnectorOidcAuthentication']]:
        """
        Authentication using harness oidc.
        """
        return pulumi.get(self, "oidc_authentication")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

